@@ -85,11 +85,17 @@ def s3_base():
         os.environ["AWS_SECRET_ACCESS_KEY"] = "foo"
     if "AWS_ACCESS_KEY_ID" not in os.environ:
         os.environ["AWS_ACCESS_KEY_ID"] = "foo"
-    proc = subprocess.Popen(shlex.split("moto_server s3 -p %s" % port))
+    proc = subprocess.Popen(
+        shlex.split("moto_server s3 -p %s" % port),
+        stderr=subprocess.DEVNULL,
+        stdout=subprocess.DEVNULL,
+        stdin=subprocess.DEVNULL,
+    )
 
     timeout = 5
     while timeout > 0:
         try:
+            print("polling for moto server")
             r = requests.get(endpoint_uri)
             if r.ok:
                 break
@@ -97,7 +103,9 @@ def s3_base():
             pass
         timeout -= 0.1
         time.sleep(0.1)
+    print("server up")
     yield
+    print("moto done")
     proc.terminate()
     proc.wait()
 
@@ -2366,3 +2374,21 @@ def test_exists_isdir(s3):
     bad_path = "s3://nyc-tlc-asdfasdf/trip data/"
     assert not s3.exists(bad_path)
     assert not s3.isdir(bad_path)
+
+
+def test_list_del_multipart(s3):
+    path = test_bucket_name + "/afile"
+    f = s3.open(path, "wb")
+    f.write(b"0" * 6 * 2**20)
+
+    out = s3.list_multipart_uploads(test_bucket_name)
+    assert [_ for _ in out if _["Key"] == "afile"]
+
+    s3.clear_multipart_uploads(test_bucket_name)
+    out = s3.list_multipart_uploads(test_bucket_name)
+    assert not [_ for _ in out if _["Key"] == "afile"]
+
+    try:
+        f.close()  # may error
+    except Exception:
+        pass
